Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(392)

Unified Diff: chrome/installer/util/auto_launch_util.h

Issue 9317002: Make the auto-launch experiment profile-aware. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Uploading again post gclient sync (no other changes) Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/installer/util/auto_launch_util.h
===================================================================
--- chrome/installer/util/auto_launch_util.h (revision 119922)
+++ chrome/installer/util/auto_launch_util.h (working copy)
@@ -1,4 +1,4 @@
-// Copyright (c) 2011 The Chromium Authors. All rights reserved.
+// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -15,16 +15,20 @@
// Returns whether the Chrome executable specified in |application_path| is set
// to auto-launch at computer startup. NOTE: |application_path| is optional and
// should be blank in most cases (as it will default to the application path of
-// the current executable).
-bool WillLaunchAtLogin(const FilePath& application_path);
+// the current executable). |profile_path| is the path to the current profile.
grt (UTC plus 2) 2012/02/01 18:45:15 "current profile" -> "profile that should be opene
+bool WillLaunchAtLogin(const FilePath& application_path,
+ const FilePath& profile_path);
// Configures whether the Chrome executable should auto-launch at computer
// startup. |application_path| is needed when |auto_launch| is true AND when
// the caller is not the process being set to auto-launch, ie. the installer.
// This is because |application_path|, if left blank, defaults to the
// application path of the current executable. If |auto_launch| is true, then it
-// will auto-launch, otherwise it will be configured not to.
-void SetWillLaunchAtLogin(bool auto_launch, const FilePath& application_path);
+// will auto-launch, otherwise it will be configured not to. |profile_path| is
+// the path to the current profile.
grt (UTC plus 2) 2012/02/01 18:45:15 same as above
+void SetWillLaunchAtLogin(bool auto_launch,
+ const FilePath& application_path,
+ const FilePath& profile_path);
} // namespace auto_launch_util

Powered by Google App Engine
This is Rietveld 408576698